@@ -26,6 +26,10 @@ knn = {
 	'weights':['uniform','distance']
 }
 
+lightgbm = {
+	'max_depth':[i for i in range(5)] + [-1]
+}
+
 mlp = {
 	'activation':['relu','tanh'],
 	'hidden_layer_sizes':[(25,),(25,25,)],
@@ -47,6 +51,10 @@ rf = {
 	'n_estimators':[100,500,1000]
 }
 
+silverkite = {
+	'changepoints':range(5)
+}
+
 svr={
 	'kernel':['linear'],
     'C':[.5,1,2,3],
